<?php
/**
 * Core Design Anonymous Links plugin for Joomla! 2.5
 * @author      Daniel Rataj, <info@greatjoomla.com>
 * @package     Joomla
 * @subpackage	Content
 * @category    Plugin
 * @version     2.5.x.2.0.2
 * @copyright	Copyright (C) 2007 - 2012 Great Joomla!, http://www.greatjoomla.com
 * @license		http://www.gnu.org/copyleft/gpl.html GNU/GPL 3
 * 
 * This file is part of Great Joomla! extension.   
 * This extension is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This extension is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

// no direct access
defined('_JEXEC') or die('Restricted access');

// Import library dependencies
jimport('joomla.plugin.plugin');

class plgContentCdAnonymousLinks extends JPlugin
{
	/**
	 * Constructor
	 *
	 * @access      protected
	 * @param       object  $subject The object to observe
	 * @param       array   $config  An array that holds the plugin configuration
	 * @since       1.5
	 */
	public function __construct(&$subject, $config)
	{
		parent::__construct($subject, $config);
		
		// define language
		$this->loadLanguage();
	}

	/**
     * Call onContentPrepare function
     * Method is called by the view.
	 *
	 * @param	string	The context of the content being passed to the plugin.
	 * @param	object	The content object.  Note $article->text is also available
	 * @param	object	The content params
	 * @param	int		The 'page' number
	 * @since	1.6
	 */
	public function onContentPrepare($context, &$article, &$params, $page = 0)
	{
		$class = $this->params->get('class', 'anonym');
		$all_links = $this->params->get('all_links', 0);
		
		// define the regular expression for the bot
		
		if ($all_links) {
			$regex = '#<a[^>]*?[^>]*?>.*?<\/a>#si';
		} else {
			$regex  = '#<a[^>]*?class="' . $class . '".*?[^>]*?>.*?<\/a>#si';
		}
        
        if (!preg_match($regex, $article->text)) return false;
        
        // replacement regular expression
        $article->text = preg_replace_callback($regex, array($this, 'replacer'), $article->text);
	}
	/**
	 * Replacer
	 * 
	 * @param $match
	 * @return string
	 */
	private function replacer(&$match) {
		
		// define html anchor link
		$ahref = $match[0];
		
		// find url in href attribute
		preg_match('#href="(.*?)"#', $ahref, $url);
		$url = $url[1];
		
		// exclude domains
		$exclude = $this->params->get('domain_exclude', '');
		
		if ($exclude) {
			$exclude = explode("\n", $exclude);
			foreach ($exclude as $exclude_link) {
				$exclude_link = trim($exclude_link);
				if (strpos($url, trim($exclude_link))) {
					return $ahref;
				}
			}
		}
		
		jimport('joomla.enviroment.uri');
		
		// URL is internal
		if (JURI::isInternal($url)) return $ahref; // return original ahref
		
		// define web service to URL procedure
		$service = $this->params->get('service', 'http://anonym.to/?');
		
		$link = str_replace('href="' . $url . '"', 'href="' . $service . $url . '"', $ahref);
		
		unset($url, $ahref, $service);

		// remove "class" if required
		$remove_class = $this->params->get('remove_class', 0);
		$class = $this->params->get('class', 'anonym');
		
		if ($remove_class) {
			// remove class and empty double spaces
			$link = str_replace(array('class="' . $class . '"', '  '), array('', ' '), $link);
			
			unset($remove_class, $class);
		}
		// return modified link
		return $link;
	}
}

?>
